<?php if(!defined('PURECLIENT_PATH')){die('Direct access not permitted');}

add_action( 'admin_menu', 'pure_profiles_menu' );
function pure_profiles_menu() {
	add_options_page( 'Pure Profiles', 'Pure Profiles', 'manage_options', 'pure_profiles', 'pure_profiles_options' );
}

function pure_profiles_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	$pure_profiles_options = array(
		'pure_profiles_host_settings'=> '', 
		'pure_profiles_username_settings' => '', 
		'pure_profiles_password_settings' =>'',
		'pure_profiles_person_ids_settings' => '',
		'pure_profiles_person_uuids_settings' => '',		
		'pure_profiles_org_uuids_settings' => '',				
		'pure_profiles_enable_styles_settings' =>'yes'
		);
	add_option('pure_profiles_options', $pure_profiles_options);
?>	
	<div class="wrap">
	<h2>Pure Profiles</h2>
	<form action="options.php" method="post">				
		<?php settings_fields('pure_profiles_options'); ?>
		<?php do_settings_sections('pure_profiles'); ?>
		<input name="cat_submit" type="submit" id="submit" class="button-primary" style="margin-top:30px;" value="Save Changes" />
		<p></p>
		<?php $options = get_option('pure_profiles_options'); ?>
	</form>	
	</div>
<?php						
}

add_action('admin_init', 'pure_profiles_admin_init');
function pure_profiles_admin_init(){
	/* if tables do not exist, then create them (this is in admin init so that it works on multisite) */
	if (! get_option('pure_profiles_db_version')) {
		require_once(PURECLIENT_PATH.'/install.php');	
		pure_profiles_install();
	}

	register_setting( 'pure_profiles_options', 'pure_profiles_options', 'pure_profiles_options_validate' );
	add_settings_section('pure_profiles_connection', '', 'pure_profiles_connection_section_text', 'pure_profiles', 'pure_profiles_connection' );
	add_settings_field('pure_profiles_hostname', 'Hostname', 'pure_profiles_host_settings', 'pure_profiles', 'pure_profiles_connection' );
	add_settings_field('pure_profiles_username', 'Username', 'pure_profiles_username_settings', 'pure_profiles', 'pure_profiles_connection' );
	add_settings_field('pure_profiles_password', 'Password', 'pure_profiles_password_settings', 'pure_profiles', 'pure_profiles_connection' );
	add_settings_section('pure_profiles_parameters', '', 'pure_profiles_parameters_section_text', 'pure_profiles', 'pure_profiles_parameters');
	add_settings_field('pure_profiles_person_uuids', 'Pure Person UUIDs', 'pure_profiles_person_uuids_settings', 'pure_profiles', 'pure_profiles_parameters' );
	add_settings_field('pure_profiles_person_ids', 'Employee IDs', 'pure_profiles_person_ids_settings', 'pure_profiles', 'pure_profiles_parameters' );	
	add_settings_field('pure_profiles_org_uuids', 'Pure Organisation UUIDs', 'pure_profiles_org_uuids_settings', 'pure_profiles', 'pure_profiles_parameters' );
	add_settings_section('pure_profiles_cron', '', 'pure_profiles_cron_section_text', 'pure_profiles', 'pure_profiles_cron' );
	add_settings_field('pure_profiles_cron_key', 'Key for Cron', 'pure_profiles_cron_key_settings', 'pure_profiles', 'pure_profiles_cron' );
	add_settings_section('pure_profiles_appearance', '', 'pure_profiles_appearance_section_text', 'pure_profiles', 'pure_profiles_appearance' );
	add_settings_field('pure_profiles_enable_styles', 'Use Default Stylesheet', 'pure_profiles_enable_styles_settings', 'pure_profiles', 'pure_profiles_appearance' );

}

function pure_profiles_connection_section_text() {
	echo '<h3>Connection Details</h3><p>Set the connection details for your Pure installation. </p>';
}

function pure_profiles_parameters_section_text() {
	echo '<h3>Parameters</h3><p>Specify the data you wish to retrieve from Pure. You can list Employee IDs, Pure UUIDs, or a mixture of both. Specifying 
	an organisation\'s Pure UUID will retrieve all of the people associated with that organisation.</p>
		<p>All formats should be in a comma separated list.</p>
		<p>Note: Pure UUIDs can be found in the URLs in the Edinburgh Research Explorer, within the brackets.</p>';
}

$cron_key = uniqid();
function pure_profiles_cron_section_text() {
	global $cron_key;
	$options = get_option( 'pure_profiles_options' );
	$cron_key = ($options['pure_profiles_cron_key_settings'] != "") ? $options['pure_profiles_cron_key_settings'] : $cron_key;	
	$cron_link = plugins_url( 'cron.php?key='.$cron_key , __FILE__ ) ;
	
	echo '<h3>Cron</h3><p>You should set up a cron to update the local cache. For example, to update every day at 4am:</p>
		<code>0 4 * * * curl '.$cron_link.' >/dev/null 2>&1</code>';
	echo '<p>It is important that the script is <strong>not</strong> called during the day or between midnight and 3am.</p>';
}

function pure_profiles_appearance_section_text() {
	echo '<h3>Appearance</h3><p>To use your own styles, untick the Use Default Stylesheet option, and implement the styles in your theme stylesheet.</p>';
}

function pure_profiles_host_settings() {
	$options = get_option( 'pure_profiles_options' );
	$value = htmlentities ( $options['pure_profiles_host_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = 'e.g. https://www-beta.pure.ed.ac.uk';
	}
	echo "<input id='pure_profiles_host_settings' name='pure_profiles_options[pure_profiles_host_settings]' size='50' type='text' value='{$value}' />";
}
function pure_profiles_username_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_username_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = 'Enter username';
	}
	echo "<input id='pure_profiles_username_settings' name='pure_profiles_options[pure_profiles_username_settings]' size='50' type='text' value='{$value}' />";
}
function pure_profiles_password_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_password_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = 'Enter password';
	}
	echo "<input id='pure_profiles_password_settings' name='pure_profiles_options[pure_profiles_password_settings]' size='50' type='password' value='{$value}' />";
}
function pure_profiles_person_uuids_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_person_uuids_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = '';
	}
	echo "<textarea id='pure_profiles_person_uuids_settings' name='pure_profiles_options[pure_profiles_person_uuids_settings]' rows='4' cols='50'>{$value}</textarea>";
}
function pure_profiles_person_ids_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_person_ids_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = '';
	}
	echo "<textarea id='pure_profiles_person_ids_settings' name='pure_profiles_options[pure_profiles_person_ids_settings]' rows='4' cols='50'>{$value}</textarea>";
}
function pure_profiles_org_uuids_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_org_uuids_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = '';
	}
	echo "<textarea id='pure_profiles_org_uuids_settings' name='pure_profiles_options[pure_profiles_org_uuids_settings]' rows='4' cols='50'>{$value}</textarea>";
}
function pure_profiles_cron_key_settings() {
	global $cron_key;
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_cron_key_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = $cron_key;
	}
	echo "<input id='pure_profiles_cron_key_settings' name='pure_profiles_options[pure_profiles_cron_key_settings]' size='50' type='text' value='{$value}' />";
}
function pure_profiles_enable_styles_settings() {
	$options = get_option('pure_profiles_options');
	$value = htmlentities ( $options['pure_profiles_enable_styles_settings'], ENT_QUOTES );
	if ( !$value ) {
		$value = 'no';
	}
	$checked = ($value=='yes') ? " checked" : "";
	echo "<input id='pure_profiles_enable_styles_settings' name='pure_profiles_options[pure_profiles_enable_styles_settings]' type='checkbox' value='yes' {$checked} />";
}

function pure_profiles_options_validate($input) {
	$options = get_option( 'pure_profiles_options' );
	$options['pure_profiles_host_settings'] = trim($input['pure_profiles_host_settings']);
	$options['pure_profiles_username_settings'] = trim($input['pure_profiles_username_settings']);
	$options['pure_profiles_password_settings'] = trim($input['pure_profiles_password_settings']);
	$options['pure_profiles_person_uuids_settings'] = trim($input['pure_profiles_person_uuids_settings']); 	
	$options['pure_profiles_person_ids_settings'] = trim($input['pure_profiles_person_ids_settings']); 
	$options['pure_profiles_org_uuids_settings'] = trim($input['pure_profiles_org_uuids_settings']); 	
	$options['pure_profiles_cron_key_settings'] = trim($input['pure_profiles_cron_key_settings']);	
	$options['pure_profiles_enable_styles_settings'] = trim($input['pure_profiles_enable_styles_settings']);		
	return $options;
}